@@ -3,11 +3,17 @@
 import argparse
 import sys
 from io import BytesIO
-from definitions import ShellcodeDefinitions 
-from transformer import ShellcodeTransformer
+from ShellcodeFormatter.definitions import ShellcodeDefinitions 
+from ShellcodeFormatter.transformer import ShellcodeTransformer
 
 
-def main(args):
+def main():
+
+    parser = argparse.ArgumentParser()
+    parser.add_argument('infile', nargs='?', type=argparse.FileType('rb'), default=sys.stdin.buffer)
+    parser.add_argument('-f', help='Output format', choices=ShellcodeDefinitions.list_definitions(), required=True, dest='format')
+    parser.add_argument('-o', '--outfile', help='Output file')
+    args = parser.parse_args()
 
     raw_shellcode:BytesIO = args.infile.read()
     definition = ShellcodeDefinitions.get_definition(args.format)
@@ -17,10 +23,4 @@ def main(args):
 
 if __name__ == '__main__':
 
-    parser = argparse.ArgumentParser()
-    parser.add_argument('infile', nargs='?', type=argparse.FileType('rb'), default=sys.stdin.buffer)
-    parser.add_argument('-f', help='Output format', choices=ShellcodeDefinitions.list_definitions(), required=True, dest='format')
-    parser.add_argument('-o', '--outfile', help='Output file')
-    args = parser.parse_args()
-
-    main(args)
\ No newline at end of file
+    main()
\ No newline at end of file
